Enum EVMError
pub enum EVMError<DBError, TransactionError = InvalidTransaction> {
Transaction(TransactionError),
Header(InvalidHeader),
Database(DBError),
Custom(String),
CustomAny(AnyError),
}Expand description
Main EVM error
Variants
Transaction(TransactionError)
Transaction validation error
Header(InvalidHeader)
Header validation error
Database(DBError)
Database error
Custom(String)
Custom error for non-standard EVM failures.
This includes fatal precompile errors (PrecompileError::Fatal and PrecompileError::FatalAny)
errors as well as any custom errors returned by handler registers.
CustomAny(AnyError)
Custom error for non-standard EVM failures.
This includes fatal precompile errors (PrecompileError::Fatal and PrecompileError::FatalAny)
errors as well as any custom errors returned by handler registers.
Implementations
impl<DBError, TransactionValidationErrorT> EVMError<DBError, TransactionValidationErrorT>
impl<DBError, TransactionValidationErrorT> EVMError<DBError, TransactionValidationErrorT>
pub fn map_db_err<F, E>(self, op: F) -> EVMError<E, TransactionValidationErrorT>where
F: FnOnce(DBError) -> E,
pub fn map_db_err<F, E>(self, op: F) -> EVMError<E, TransactionValidationErrorT>where
F: FnOnce(DBError) -> E,
Maps a DBError to a new error type using the provided closure, leaving other variants unchanged.