Function eip7623_check_gas_floor
pub fn eip7623_check_gas_floor(
gas: &mut Gas,
init_and_floor_gas: InitialAndFloorGas,
)Expand description
Ensures minimum gas floor is spent according to EIP-7623.
Per EIP-8037, gas used before refund is tx.gas - gas_left - state_gas_reservoir.
The floor applies to this combined total, not just regular gas.