Struct EthPrecompileOutput
pub struct EthPrecompileOutput {
pub gas_used: u64,
pub bytes: Bytes,
}Expand description
Simple precompile execution output used by individual Ethereum precompile functions.
Contains only the gas used and output bytes. For the richer output type
with state gas accounting and halt support, see PrecompileOutput.
Fields
gas_used: u64Gas used by the precompile.
bytes: BytesOutput bytes
Implementations
impl EthPrecompileOutput
impl EthPrecompileOutput
pub fn new(gas_used: u64, bytes: Bytes) -> EthPrecompileOutput
pub fn new(gas_used: u64, bytes: Bytes) -> EthPrecompileOutput
Returns new precompile output with the given gas used and output bytes.