dupn

Function dupn 

pub fn dupn<WIRE, H>(context: InstructionContext<'_, H, WIRE>)
where WIRE: InterpreterTypes, H: ?Sized,
Implements the DUPN instruction.

Duplicates the Nth stack item to the top of the stack, with N given by an immediate.